EncodablePrimitive

Enum EncodablePrimitive 

pub enum EncodablePrimitive<'a> {
Show 15 variants U8(u8), OwnedU8(u8), U16(u16), Bool(bool), U24(U24), U256(Inner<'a, true, 32, 0, 0>), Signature(Inner<'a, true, 64, 0, 0>), U32(u32), U32AsRef(Inner<'a, true, 4, 0, 0>), F32(f32), U64(u64), B032(Inner<'a, false, 1, 1, 32>), B0255(Inner<'a, false, 1, 1, 255>), B064K(Inner<'a, false, 1, 2, binary_codec_sv2::::datatypes::non_copy_data_types::B064K::{constant#3}>), B016M(Inner<'a, false, 1, 3, binary_codec_sv2::::datatypes::non_copy_data_types::B016M::{constant#3}>),
}
The EncodablePrimitive enum defines primitive types that can be encoded.

The enum represents various data types, such a integers, bool, and byte array that can be encoded into a byte representation. Each variant holds a specific type, and encoding logic is provided through the encode method.

Variants



U8(u8)

U8 Primitive, representing a byte



OwnedU8(u8)

Owned U8 Primitive, representing an owned byte



U16(u16)

U16 Primitive, representing a u16 type



Bool(bool)

Bool Primitive, representing a bool type



U24(U24)

U24 Primitive, representing a U24 type



U256(Inner<'a, true, 32, 0, 0>)

U256 Primitive, representing a U256 type



Signature(Inner<'a, true, 64, 0, 0>)

Signature Primitive, representing a Signature type



U32(u32)

U32 Primitive, representing a u32 type



U32AsRef(Inner<'a, true, 4, 0, 0>)

U32AsRef Primitive, representing a U32AsRef type



F32(f32)

F32 Primitive, representing a f32 type



U64(u64)

U64 Primitive, representing a u64 type



B032(Inner<'a, false, 1, 1, 32>)

B032 Primitive, representing a B032 type



B0255(Inner<'a, false, 1, 1, 255>)

B0255 Primitive, representing a B0255 type



B064K(Inner<'a, false, 1, 2, binary_codec_sv2::::datatypes::non_copy_data_types::B064K::{constant#3}>)

B064K Primitive, representing a B064K type



B016M(Inner<'a, false, 1, 3, binary_codec_sv2::::datatypes::non_copy_data_types::B016M::{constant#3}>)

B016M Primitive, representing a B016M type