Trait binary_sv2::Fixed
source · pub trait Fixed {
const SIZE: usize;
}Expand description
Implemented by all the primitives with a fixed size
Required Associated Constants
Object Safety
This trait is not object safe.
pub trait Fixed {
const SIZE: usize;
}Implemented by all the primitives with a fixed size