pub trait GetSize {
// Required method
fn get_size(&self) -> usize;
}Expand description
GetSize is a trait defining a single function that calculates the total size of an
encodable type.
pub trait GetSize {
// Required method
fn get_size(&self) -> usize;
}GetSize is a trait defining a single function that calculates the total size of an
encodable type.